LineRenderPipeline

Struct LineRenderPipeline 

pub struct LineRenderPipeline {
    pub pipeline: RenderPipeline,
    pub camera_buffer: Buffer,
    pub camera_bind_group: BindGroup,
    pub camera_bind_group_layout: BindGroupLayout,
    pub instance_buffer: Option<Buffer>,
    pub num_instances: u32,
}
Pipeline de renderizado GPU para el dibujo acelerado de series temporales por instancias.

Fields

pipeline: RenderPipelinecamera_buffer: Buffercamera_bind_group: BindGroupcamera_bind_group_layout: BindGroupLayoutinstance_buffer: Option<Buffer>num_instances: u32

Implementations

Source

impl LineRenderPipeline

pub fn new( device: &Device, surface_format: TextureFormat, camera: &ViewportCamera, ) -> Self

Crea el pipeline de renderizado wgpu utilizando el shader WGSL instanciado.

pub fn update_camera(&self, queue: &Queue, camera: &ViewportCamera)

Actualiza la matriz de cámara en la GPU sin costo de re-asignación de geometría ($0\text{ ms}$ overhead).

pub fn upload_instances( &mut self, device: &Device, pairs: &[MinMaxPair], x_step: f32, )

Carga los datos de las instancias de pares MinMax en el VBO de la GPU.

pub fn render<'a>(&'a self, render_pass: &mut RenderPass<'a>)

Ejecuta el pase de renderizado en GPU.